# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/scoreboard.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/scoreboard.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65olymp/judge/scoreboard.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xd3\x05\n\nScoreboard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x08\x12\x0f\n\x07visible\x18\x03 \x01(\x08\x12\x17\n\x0f\x61ttempt_penalty\x18\x1e \x01(\r\x12+\n\x04type\x18\n \x01(\x0e\x32\x1d.eolymp.judge.Scoreboard.Type\x12/\n\x06status\x18\x0b \x01(\x0e\x32\x1f.eolymp.judge.Scoreboard.Status\x12/\n\x0b\x66reeze_time\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\tfreeze_in\x18\x16 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\x87\x01\n\x03Row\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\x31\n\tbreakdown\x18\x0c \x03(\x0b\x32\x1e.eolymp.judge.Scoreboard.Score\x1a\xc4\x01\n\x05Score\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12\x0f\n\x07penalty\x18\x03 \x01(\x02\x12\x0e\n\x06solved\x18\x04 \x01(\x08\x12\x12\n\npercentage\x18\x05 \x01(\x02\x12\x0f\n\x07submits\x18\x06 \x01(\r\x12\x10\n\x08\x61ttempts\x18\x07 \x01(\r\x12-\n\tsolved_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tsolved_in\x18\t \x01(\r\"#\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03IOI\x10\x01\x12\x08\n\x04ICPC\x10\x02\"=\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\n\n\x06\x46ROZEN\x10\x02\x12\x0e\n\nREBUILDING\x10\x03\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])



_SCOREBOARD_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.judge.Scoreboard.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IOI', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=738,
  serialized_end=773,
)
_sym_db.RegisterEnumDescriptor(_SCOREBOARD_TYPE)

_SCOREBOARD_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Scoreboard.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FROZEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REBUILDING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=775,
  serialized_end=836,
)
_sym_db.RegisterEnumDescriptor(_SCOREBOARD_STATUS)


_SCOREBOARD_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='eolymp.judge.Scoreboard.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.Scoreboard.Row.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.Scoreboard.Row.scoreboard_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Scoreboard.Row.score', index=2,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.judge.Scoreboard.Row.penalty', index=3,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='breakdown', full_name='eolymp.judge.Scoreboard.Row.breakdown', index=4,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=537,
)

_SCOREBOARD_SCORE = _descriptor.Descriptor(
  name='Score',
  full_name='eolymp.judge.Scoreboard.Score',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.Scoreboard.Score.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Scoreboard.Score.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.judge.Scoreboard.Score.penalty', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solved', full_name='eolymp.judge.Scoreboard.Score.solved', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='eolymp.judge.Scoreboard.Score.percentage', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submits', full_name='eolymp.judge.Scoreboard.Score.submits', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='eolymp.judge.Scoreboard.Score.attempts', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solved_at', full_name='eolymp.judge.Scoreboard.Score.solved_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solved_in', full_name='eolymp.judge.Scoreboard.Score.solved_in', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=736,
)

_SCOREBOARD = _descriptor.Descriptor(
  name='Scoreboard',
  full_name='eolymp.judge.Scoreboard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Scoreboard.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.judge.Scoreboard.name', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default', full_name='eolymp.judge.Scoreboard.default', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='eolymp.judge.Scoreboard.visible', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attempt_penalty', full_name='eolymp.judge.Scoreboard.attempt_penalty', index=4,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.Scoreboard.type', index=5,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Scoreboard.status', index=6,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freeze_time', full_name='eolymp.judge.Scoreboard.freeze_time', index=7,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freeze_in', full_name='eolymp.judge.Scoreboard.freeze_in', index=8,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOREBOARD_ROW, _SCOREBOARD_SCORE, ],
  enum_types=[
    _SCOREBOARD_TYPE,
    _SCOREBOARD_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=836,
)

_SCOREBOARD_ROW.fields_by_name['breakdown'].message_type = _SCOREBOARD_SCORE
_SCOREBOARD_ROW.containing_type = _SCOREBOARD
_SCOREBOARD_SCORE.fields_by_name['solved_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOREBOARD_SCORE.containing_type = _SCOREBOARD
_SCOREBOARD.fields_by_name['type'].enum_type = _SCOREBOARD_TYPE
_SCOREBOARD.fields_by_name['status'].enum_type = _SCOREBOARD_STATUS
_SCOREBOARD.fields_by_name['freeze_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOREBOARD.fields_by_name['freeze_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SCOREBOARD_TYPE.containing_type = _SCOREBOARD
_SCOREBOARD_STATUS.containing_type = _SCOREBOARD
DESCRIPTOR.message_types_by_name['Scoreboard'] = _SCOREBOARD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scoreboard = _reflection.GeneratedProtocolMessageType('Scoreboard', (_message.Message,), {

  'Row' : _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {
    'DESCRIPTOR' : _SCOREBOARD_ROW,
    '__module__' : 'eolymp.judge.scoreboard_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Scoreboard.Row)
    })
  ,

  'Score' : _reflection.GeneratedProtocolMessageType('Score', (_message.Message,), {
    'DESCRIPTOR' : _SCOREBOARD_SCORE,
    '__module__' : 'eolymp.judge.scoreboard_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Scoreboard.Score)
    })
  ,
  'DESCRIPTOR' : _SCOREBOARD,
  '__module__' : 'eolymp.judge.scoreboard_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Scoreboard)
  })
_sym_db.RegisterMessage(Scoreboard)
_sym_db.RegisterMessage(Scoreboard.Row)
_sym_db.RegisterMessage(Scoreboard.Score)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/executor.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.executor import task_pb2 as eolymp_dot_executor_dot_task__pb2
from eolymp.executor import language_pb2 as eolymp_dot_executor_dot_language__pb2
from eolymp.executor import runtime_pb2 as eolymp_dot_executor_dot_runtime__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/executor.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/executor/executor.proto\x12\x0f\x65olymp.executor\x1a!eolymp/wellknown/expression.proto\x1a\x1a\x65olymp/executor/task.proto\x1a\x1e\x65olymp/executor/language.proto\x1a\x1d\x65olymp/executor/runtime.proto\"6\n\x0f\x43reateTaskInput\x12#\n\x04task\x18\x01 \x01(\x0b\x32\x15.eolymp.executor.Task\"\x12\n\x10\x43reateTaskOutput\",\n\x15\x44\x65scribeLanguageInput\x12\x13\n\x0blanguage_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeLanguageOutput\x12+\n\x08language\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Language\"\xf0\x01\n\x12ListLanguagesInput\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.executor.ListLanguagesInput.Filter\x1a\x9c\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"?\n\x13ListLanguagesOutput\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.executor.Language\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"B\n\x15\x44\x65scribeRuntimeOutput\x12)\n\x07runtime\x18\x01 \x01(\x0b\x32\x18.eolymp.executor.Runtime\"\xcb\x02\n\x10ListRuntimeInput\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.executor.ListRuntimeInput.Filter\x1a\xfb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12,\n\x04lang\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07version\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"<\n\x11ListRuntimeOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.executor.Runtime\"/\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t2\xfe\x03\n\x08\x45xecutor\x12\x65\n\x10\x44\x65scribeLanguage\x12&.eolymp.executor.DescribeLanguageInput\x1a\'.eolymp.executor.DescribeLanguageOutput\"\x00\x12\\\n\rListLanguages\x12#.eolymp.executor.ListLanguagesInput\x1a$.eolymp.executor.ListLanguagesOutput\"\x00\x12\x62\n\x0f\x44\x65scribeRuntime\x12%.eolymp.executor.DescribeRuntimeInput\x1a&.eolymp.executor.DescribeRuntimeOutput\"\x00\x12V\n\x0bListRuntime\x12!.eolymp.executor.ListRuntimeInput\x1a\".eolymp.executor.ListRuntimeOutput\"\x00\x12q\n\x14\x44\x65scribeCodeTemplate\x12*.eolymp.executor.DescribeCodeTemplateInput\x1a+.eolymp.executor.DescribeCodeTemplateOutput\"\x00\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
  ,
  dependencies=[eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_executor_dot_task__pb2.DESCRIPTOR,eolymp_dot_executor_dot_language__pb2.DESCRIPTOR,eolymp_dot_executor_dot_runtime__pb2.DESCRIPTOR,])




_CREATETASKINPUT = _descriptor.Descriptor(
  name='CreateTaskInput',
  full_name='eolymp.executor.CreateTaskInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='eolymp.executor.CreateTaskInput.task', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=231,
)


_CREATETASKOUTPUT = _descriptor.Descriptor(
  name='CreateTaskOutput',
  full_name='eolymp.executor.CreateTaskOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=251,
)


_DESCRIBELANGUAGEINPUT = _descriptor.Descriptor(
  name='DescribeLanguageInput',
  full_name='eolymp.executor.DescribeLanguageInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_id', full_name='eolymp.executor.DescribeLanguageInput.language_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=297,
)


_DESCRIBELANGUAGEOUTPUT = _descriptor.Descriptor(
  name='DescribeLanguageOutput',
  full_name='eolymp.executor.DescribeLanguageOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='eolymp.executor.DescribeLanguageOutput.language', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=368,
)


_LISTLANGUAGESINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.executor.ListLanguagesInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.executor.ListLanguagesInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.executor.ListLanguagesInput.Filter.name', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='eolymp.executor.ListLanguagesInput.Filter.deprecated', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=611,
)

_LISTLANGUAGESINPUT = _descriptor.Descriptor(
  name='ListLanguagesInput',
  full_name='eolymp.executor.ListLanguagesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.executor.ListLanguagesInput.filters', index=0,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTLANGUAGESINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=611,
)


_LISTLANGUAGESOUTPUT = _descriptor.Descriptor(
  name='ListLanguagesOutput',
  full_name='eolymp.executor.ListLanguagesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.executor.ListLanguagesOutput.items', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=676,
)


_DESCRIBERUNTIMEINPUT = _descriptor.Descriptor(
  name='DescribeRuntimeInput',
  full_name='eolymp.executor.DescribeRuntimeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_id', full_name='eolymp.executor.DescribeRuntimeInput.runtime_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=720,
)


_DESCRIBERUNTIMEOUTPUT = _descriptor.Descriptor(
  name='DescribeRuntimeOutput',
  full_name='eolymp.executor.DescribeRuntimeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime', full_name='eolymp.executor.DescribeRuntimeOutput.runtime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=788,
)


_LISTRUNTIMEINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.executor.ListRuntimeInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.executor.ListRuntimeInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.ListRuntimeInput.Filter.lang', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='eolymp.executor.ListRuntimeInput.Filter.version', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.executor.ListRuntimeInput.Filter.name', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='eolymp.executor.ListRuntimeInput.Filter.deprecated', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=1122,
)

_LISTRUNTIMEINPUT = _descriptor.Descriptor(
  name='ListRuntimeInput',
  full_name='eolymp.executor.ListRuntimeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.executor.ListRuntimeInput.filters', index=0,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTRUNTIMEINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=1122,
)


_LISTRUNTIMEOUTPUT = _descriptor.Descriptor(
  name='ListRuntimeOutput',
  full_name='eolymp.executor.ListRuntimeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.executor.ListRuntimeOutput.items', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1184,
)


_DESCRIBECODETEMPLATEINPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateInput',
  full_name='eolymp.executor.DescribeCodeTemplateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_id', full_name='eolymp.executor.DescribeCodeTemplateInput.runtime_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1233,
)


_DESCRIBECODETEMPLATEOUTPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateOutput',
  full_name='eolymp.executor.DescribeCodeTemplateOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='eolymp.executor.DescribeCodeTemplateOutput.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1281,
)

_CREATETASKINPUT.fields_by_name['task'].message_type = eolymp_dot_executor_dot_task__pb2._TASK
_DESCRIBELANGUAGEOUTPUT.fields_by_name['language'].message_type = eolymp_dot_executor_dot_language__pb2._LANGUAGE
_LISTLANGUAGESINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTLANGUAGESINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTLANGUAGESINPUT_FILTER.fields_by_name['deprecated'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTLANGUAGESINPUT_FILTER.containing_type = _LISTLANGUAGESINPUT
_LISTLANGUAGESINPUT.fields_by_name['filters'].message_type = _LISTLANGUAGESINPUT_FILTER
_LISTLANGUAGESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_executor_dot_language__pb2._LANGUAGE
_DESCRIBERUNTIMEOUTPUT.fields_by_name['runtime'].message_type = eolymp_dot_executor_dot_runtime__pb2._RUNTIME
_LISTRUNTIMEINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTRUNTIMEINPUT_FILTER.fields_by_name['lang'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTRUNTIMEINPUT_FILTER.fields_by_name['version'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTRUNTIMEINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTRUNTIMEINPUT_FILTER.fields_by_name['deprecated'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTRUNTIMEINPUT_FILTER.containing_type = _LISTRUNTIMEINPUT
_LISTRUNTIMEINPUT.fields_by_name['filters'].message_type = _LISTRUNTIMEINPUT_FILTER
_LISTRUNTIMEOUTPUT.fields_by_name['items'].message_type = eolymp_dot_executor_dot_runtime__pb2._RUNTIME
DESCRIPTOR.message_types_by_name['CreateTaskInput'] = _CREATETASKINPUT
DESCRIPTOR.message_types_by_name['CreateTaskOutput'] = _CREATETASKOUTPUT
DESCRIPTOR.message_types_by_name['DescribeLanguageInput'] = _DESCRIBELANGUAGEINPUT
DESCRIPTOR.message_types_by_name['DescribeLanguageOutput'] = _DESCRIBELANGUAGEOUTPUT
DESCRIPTOR.message_types_by_name['ListLanguagesInput'] = _LISTLANGUAGESINPUT
DESCRIPTOR.message_types_by_name['ListLanguagesOutput'] = _LISTLANGUAGESOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRuntimeInput'] = _DESCRIBERUNTIMEINPUT
DESCRIPTOR.message_types_by_name['DescribeRuntimeOutput'] = _DESCRIBERUNTIMEOUTPUT
DESCRIPTOR.message_types_by_name['ListRuntimeInput'] = _LISTRUNTIMEINPUT
DESCRIPTOR.message_types_by_name['ListRuntimeOutput'] = _LISTRUNTIMEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateInput'] = _DESCRIBECODETEMPLATEINPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateOutput'] = _DESCRIBECODETEMPLATEOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTaskInput = _reflection.GeneratedProtocolMessageType('CreateTaskInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETASKINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.CreateTaskInput)
  })
_sym_db.RegisterMessage(CreateTaskInput)

CreateTaskOutput = _reflection.GeneratedProtocolMessageType('CreateTaskOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETASKOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.CreateTaskOutput)
  })
_sym_db.RegisterMessage(CreateTaskOutput)

DescribeLanguageInput = _reflection.GeneratedProtocolMessageType('DescribeLanguageInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELANGUAGEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeLanguageInput)
  })
_sym_db.RegisterMessage(DescribeLanguageInput)

DescribeLanguageOutput = _reflection.GeneratedProtocolMessageType('DescribeLanguageOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELANGUAGEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeLanguageOutput)
  })
_sym_db.RegisterMessage(DescribeLanguageOutput)

ListLanguagesInput = _reflection.GeneratedProtocolMessageType('ListLanguagesInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTLANGUAGESINPUT_FILTER,
    '__module__' : 'eolymp.executor.executor_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.ListLanguagesInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTLANGUAGESINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListLanguagesInput)
  })
_sym_db.RegisterMessage(ListLanguagesInput)
_sym_db.RegisterMessage(ListLanguagesInput.Filter)

ListLanguagesOutput = _reflection.GeneratedProtocolMessageType('ListLanguagesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTLANGUAGESOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListLanguagesOutput)
  })
_sym_db.RegisterMessage(ListLanguagesOutput)

DescribeRuntimeInput = _reflection.GeneratedProtocolMessageType('DescribeRuntimeInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNTIMEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeRuntimeInput)
  })
_sym_db.RegisterMessage(DescribeRuntimeInput)

DescribeRuntimeOutput = _reflection.GeneratedProtocolMessageType('DescribeRuntimeOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNTIMEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeRuntimeOutput)
  })
_sym_db.RegisterMessage(DescribeRuntimeOutput)

ListRuntimeInput = _reflection.GeneratedProtocolMessageType('ListRuntimeInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTRUNTIMEINPUT_FILTER,
    '__module__' : 'eolymp.executor.executor_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.ListRuntimeInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTRUNTIMEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListRuntimeInput)
  })
_sym_db.RegisterMessage(ListRuntimeInput)
_sym_db.RegisterMessage(ListRuntimeInput.Filter)

ListRuntimeOutput = _reflection.GeneratedProtocolMessageType('ListRuntimeOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNTIMEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListRuntimeOutput)
  })
_sym_db.RegisterMessage(ListRuntimeOutput)

DescribeCodeTemplateInput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeCodeTemplateInput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateInput)

DescribeCodeTemplateOutput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeCodeTemplateOutput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateOutput)


DESCRIPTOR._options = None

_EXECUTOR = _descriptor.ServiceDescriptor(
  name='Executor',
  full_name='eolymp.executor.Executor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1284,
  serialized_end=1794,
  methods=[
  _descriptor.MethodDescriptor(
    name='DescribeLanguage',
    full_name='eolymp.executor.Executor.DescribeLanguage',
    index=0,
    containing_service=None,
    input_type=_DESCRIBELANGUAGEINPUT,
    output_type=_DESCRIBELANGUAGEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLanguages',
    full_name='eolymp.executor.Executor.ListLanguages',
    index=1,
    containing_service=None,
    input_type=_LISTLANGUAGESINPUT,
    output_type=_LISTLANGUAGESOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRuntime',
    full_name='eolymp.executor.Executor.DescribeRuntime',
    index=2,
    containing_service=None,
    input_type=_DESCRIBERUNTIMEINPUT,
    output_type=_DESCRIBERUNTIMEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRuntime',
    full_name='eolymp.executor.Executor.ListRuntime',
    index=3,
    containing_service=None,
    input_type=_LISTRUNTIMEINPUT,
    output_type=_LISTRUNTIMEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeCodeTemplate',
    full_name='eolymp.executor.Executor.DescribeCodeTemplate',
    index=4,
    containing_service=None,
    input_type=_DESCRIBECODETEMPLATEINPUT,
    output_type=_DESCRIBECODETEMPLATEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXECUTOR)

DESCRIPTOR.services_by_name['Executor'] = _EXECUTOR

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/apollo/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/apollo/events.proto',
  package='eolymp.apollo',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/apollo;apollo',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/apollo/events.proto\x12\reolymp.apollo\"5\n\x0eStarAddedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"7\n\x10StarRemovedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\tB5Z3github.com/eolymp/contracts/go/eolymp/apollo;apollob\x06proto3'
)




_STARADDEDEVENT = _descriptor.Descriptor(
  name='StarAddedEvent',
  full_name='eolymp.apollo.StarAddedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarAddedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarAddedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=98,
)


_STARREMOVEDEVENT = _descriptor.Descriptor(
  name='StarRemovedEvent',
  full_name='eolymp.apollo.StarRemovedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarRemovedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarRemovedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=155,
)

DESCRIPTOR.message_types_by_name['StarAddedEvent'] = _STARADDEDEVENT
DESCRIPTOR.message_types_by_name['StarRemovedEvent'] = _STARREMOVEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StarAddedEvent = _reflection.GeneratedProtocolMessageType('StarAddedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARADDEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarAddedEvent)
  })
_sym_db.RegisterMessage(StarAddedEvent)

StarRemovedEvent = _reflection.GeneratedProtocolMessageType('StarRemovedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARREMOVEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarRemovedEvent)
  })
_sym_db.RegisterMessage(StarRemovedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/verifier.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/verifier.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/executor/verifier.proto\x12\x0f\x65olymp.executor\"\xcb\x01\n\x08Verifier\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.eolymp.executor.Verifier.Type\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x11\n\tprecision\x18\x04 \x01(\x05\x12\x16\n\x0e\x63\x61se_sensitive\x18\x05 \x01(\x08\"H\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06TOKENS\x10\x01\x12\t\n\x05LINES\x10\x02\x12\x0b\n\x07PROGRAM\x10\x03\x12\x12\n\x0eLEGACY_PROGRAM\x10\x04\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
)



_VERIFIER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.executor.Verifier.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOKENS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRAM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEGACY_PROGRAM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=183,
  serialized_end=255,
)
_sym_db.RegisterEnumDescriptor(_VERIFIER_TYPE)


_VERIFIER = _descriptor.Descriptor(
  name='Verifier',
  full_name='eolymp.executor.Verifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.executor.Verifier.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.Verifier.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.executor.Verifier.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='precision', full_name='eolymp.executor.Verifier.precision', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_sensitive', full_name='eolymp.executor.Verifier.case_sensitive', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VERIFIER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=255,
)

_VERIFIER.fields_by_name['type'].enum_type = _VERIFIER_TYPE
_VERIFIER_TYPE.containing_type = _VERIFIER
DESCRIPTOR.message_types_by_name['Verifier'] = _VERIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Verifier = _reflection.GeneratedProtocolMessageType('Verifier', (_message.Message,), {
  'DESCRIPTOR' : _VERIFIER,
  '__module__' : 'eolymp.executor.verifier_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Verifier)
  })
_sym_db.RegisterMessage(Verifier)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testset.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import feedback_pb2 as eolymp_dot_atlas_dot_feedback__pb2
from eolymp.atlas import scoring_pb2 as eolymp_dot_atlas_dot_scoring__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/testset.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/atlas/testset.proto\x12\x0c\x65olymp.atlas\x1a\x1b\x65olymp/atlas/feedback.proto\x1a\x1a\x65olymp/atlas/scoring.proto\"\xf9\x01\n\x07Testset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\x12\x12\n\ntime_limit\x18\n \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0b \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\x0c \x01(\x04\x12\x14\n\x0c\x64\x65pendencies\x18\x14 \x03(\r\x12/\n\x0cscoring_mode\x18\x1e \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18( \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicyB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
  ,
  dependencies=[eolymp_dot_atlas_dot_feedback__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_scoring__pb2.DESCRIPTOR,])




_TESTSET = _descriptor.Descriptor(
  name='Testset',
  full_name='eolymp.atlas.Testset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.Testset.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.Testset.problem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.atlas.Testset.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_limit', full_name='eolymp.atlas.Testset.time_limit', index=3,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_limit', full_name='eolymp.atlas.Testset.memory_limit', index=4,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size_limit', full_name='eolymp.atlas.Testset.file_size_limit', index=5,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dependencies', full_name='eolymp.atlas.Testset.dependencies', index=6,
      number=20, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoring_mode', full_name='eolymp.atlas.Testset.scoring_mode', index=7,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback_policy', full_name='eolymp.atlas.Testset.feedback_policy', index=8,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=351,
)

_TESTSET.fields_by_name['scoring_mode'].enum_type = eolymp_dot_atlas_dot_scoring__pb2._SCORINGMODE
_TESTSET.fields_by_name['feedback_policy'].enum_type = eolymp_dot_atlas_dot_feedback__pb2._FEEDBACKPOLICY
DESCRIPTOR.message_types_by_name['Testset'] = _TESTSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Testset = _reflection.GeneratedProtocolMessageType('Testset', (_message.Message,), {
  'DESCRIPTOR' : _TESTSET,
  '__module__' : 'eolymp.atlas.testset_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.Testset)
  })
_sym_db.RegisterMessage(Testset)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import permission_pb2 as eolymp_dot_atlas_dot_permission__pb2
from eolymp.atlas import submission_pb2 as eolymp_dot_atlas_dot_submission__pb2
from eolymp.atlas import score_pb2 as eolymp_dot_atlas_dot_score__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/events.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x65olymp/atlas/events.proto\x12\x0c\x65olymp.atlas\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1d\x65olymp/atlas/permission.proto\x1a\x1d\x65olymp/atlas/submission.proto\x1a\x18\x65olymp/atlas/score.proto\"=\n\x13ProblemUpdatedEvent\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\")\n\x13ProblemDeletedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"[\n\x17PermissionsUpdatedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12,\n\npermission\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Permission\">\n\x17PermissionsDeletedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"W\n\x17SubmissionCompleteEvent\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\x12\x0e\n\x06update\x18\x02 \x01(\x08\"7\n\x11ScoreUpdatedEvent\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.atlas.ScoreB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
  ,
  dependencies=[eolymp_dot_atlas_dot_problem__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_permission__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_submission__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_score__pb2.DESCRIPTOR,])




_PROBLEMUPDATEDEVENT = _descriptor.Descriptor(
  name='ProblemUpdatedEvent',
  full_name='eolymp.atlas.ProblemUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.atlas.ProblemUpdatedEvent.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=220,
)


_PROBLEMDELETEDEVENT = _descriptor.Descriptor(
  name='ProblemDeletedEvent',
  full_name='eolymp.atlas.ProblemDeletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ProblemDeletedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=263,
)


_PERMISSIONSUPDATEDEVENT = _descriptor.Descriptor(
  name='PermissionsUpdatedEvent',
  full_name='eolymp.atlas.PermissionsUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.PermissionsUpdatedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='eolymp.atlas.PermissionsUpdatedEvent.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=356,
)


_PERMISSIONSDELETEDEVENT = _descriptor.Descriptor(
  name='PermissionsDeletedEvent',
  full_name='eolymp.atlas.PermissionsDeletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.PermissionsDeletedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.atlas.PermissionsDeletedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=420,
)


_SUBMISSIONCOMPLETEEVENT = _descriptor.Descriptor(
  name='SubmissionCompleteEvent',
  full_name='eolymp.atlas.SubmissionCompleteEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.atlas.SubmissionCompleteEvent.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='eolymp.atlas.SubmissionCompleteEvent.update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=509,
)


_SCOREUPDATEDEVENT = _descriptor.Descriptor(
  name='ScoreUpdatedEvent',
  full_name='eolymp.atlas.ScoreUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.atlas.ScoreUpdatedEvent.score', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=566,
)

_PROBLEMUPDATEDEVENT.fields_by_name['problem'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_PERMISSIONSUPDATEDEVENT.fields_by_name['permission'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
_SUBMISSIONCOMPLETEEVENT.fields_by_name['submission'].message_type = eolymp_dot_atlas_dot_submission__pb2._SUBMISSION
_SCOREUPDATEDEVENT.fields_by_name['score'].message_type = eolymp_dot_atlas_dot_score__pb2._SCORE
DESCRIPTOR.message_types_by_name['ProblemUpdatedEvent'] = _PROBLEMUPDATEDEVENT
DESCRIPTOR.message_types_by_name['ProblemDeletedEvent'] = _PROBLEMDELETEDEVENT
DESCRIPTOR.message_types_by_name['PermissionsUpdatedEvent'] = _PERMISSIONSUPDATEDEVENT
DESCRIPTOR.message_types_by_name['PermissionsDeletedEvent'] = _PERMISSIONSDELETEDEVENT
DESCRIPTOR.message_types_by_name['SubmissionCompleteEvent'] = _SUBMISSIONCOMPLETEEVENT
DESCRIPTOR.message_types_by_name['ScoreUpdatedEvent'] = _SCOREUPDATEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProblemUpdatedEvent = _reflection.GeneratedProtocolMessageType('ProblemUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PROBLEMUPDATEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ProblemUpdatedEvent)
  })
_sym_db.RegisterMessage(ProblemUpdatedEvent)

ProblemDeletedEvent = _reflection.GeneratedProtocolMessageType('ProblemDeletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PROBLEMDELETEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ProblemDeletedEvent)
  })
_sym_db.RegisterMessage(ProblemDeletedEvent)

PermissionsUpdatedEvent = _reflection.GeneratedProtocolMessageType('PermissionsUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONSUPDATEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.PermissionsUpdatedEvent)
  })
_sym_db.RegisterMessage(PermissionsUpdatedEvent)

PermissionsDeletedEvent = _reflection.GeneratedProtocolMessageType('PermissionsDeletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONSDELETEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.PermissionsDeletedEvent)
  })
_sym_db.RegisterMessage(PermissionsDeletedEvent)

SubmissionCompleteEvent = _reflection.GeneratedProtocolMessageType('SubmissionCompleteEvent', (_message.Message,), {
  'DESCRIPTOR' : _SUBMISSIONCOMPLETEEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.SubmissionCompleteEvent)
  })
_sym_db.RegisterMessage(SubmissionCompleteEvent)

ScoreUpdatedEvent = _reflection.GeneratedProtocolMessageType('ScoreUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _SCOREUPDATEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ScoreUpdatedEvent)
  })
_sym_db.RegisterMessage(ScoreUpdatedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/typewriter.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/typewriter/typewriter.proto',
  package='eolymp.typewriter',
  syntax='proto3',
  serialized_options=b'Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriter',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"eolymp/typewriter/typewriter.proto\x12\x11\x65olymp.typewriter\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\"2\n\x10UploadAssetInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"!\n\x11UploadAssetOutput\x12\x0c\n\x04link\x18\x01 \x01(\t2\x96\x01\n\nTypewriter\x12\x87\x01\n\x0bUploadAsset\x12#.eolymp.typewriter.UploadAssetInput\x1a$.eolymp.typewriter.UploadAssetOutput\"-\x82\xe3\n\x1a\x8a\xe3\n\x16typewriter:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\ndB=Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriterb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,])




_UPLOADASSETINPUT = _descriptor.Descriptor(
  name='UploadAssetInput',
  full_name='eolymp.typewriter.UploadAssetInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='eolymp.typewriter.UploadAssetInput.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='eolymp.typewriter.UploadAssetInput.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=175,
)


_UPLOADASSETOUTPUT = _descriptor.Descriptor(
  name='UploadAssetOutput',
  full_name='eolymp.typewriter.UploadAssetOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='eolymp.typewriter.UploadAssetOutput.link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=210,
)

DESCRIPTOR.message_types_by_name['UploadAssetInput'] = _UPLOADASSETINPUT
DESCRIPTOR.message_types_by_name['UploadAssetOutput'] = _UPLOADASSETOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadAssetInput = _reflection.GeneratedProtocolMessageType('UploadAssetInput', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADASSETINPUT,
  '__module__' : 'eolymp.typewriter.typewriter_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.typewriter.UploadAssetInput)
  })
_sym_db.RegisterMessage(UploadAssetInput)

UploadAssetOutput = _reflection.GeneratedProtocolMessageType('UploadAssetOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADASSETOUTPUT,
  '__module__' : 'eolymp.typewriter.typewriter_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.typewriter.UploadAssetOutput)
  })
_sym_db.RegisterMessage(UploadAssetOutput)


DESCRIPTOR._options = None

_TYPEWRITER = _descriptor.ServiceDescriptor(
  name='Typewriter',
  full_name='eolymp.typewriter.Typewriter',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=213,
  serialized_end=363,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadAsset',
    full_name='eolymp.typewriter.Typewriter.UploadAsset',
    index=0,
    containing_service=None,
    input_type=_UPLOADASSETINPUT,
    output_type=_UPLOADASSETOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026typewriter:asset:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TYPEWRITER)

DESCRIPTOR.services_by_name['Typewriter'] = _TYPEWRITER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/permission.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/permission.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65olymp/atlas/permission.proto\x12\x0c\x65olymp.atlas\"\x87\x01\n\nPermission\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12+\n\x04role\x18\x03 \x01(\x0e\x32\x1d.eolymp.atlas.Permission.Role\"\'\n\x04Role\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05OWNER\x10\x01\x12\n\n\x06\x45\x44ITOR\x10\x02\x42\x33Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
)



_PERMISSION_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='eolymp.atlas.Permission.Role',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OWNER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EDITOR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=144,
  serialized_end=183,
)
_sym_db.RegisterEnumDescriptor(_PERMISSION_ROLE)


_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='eolymp.atlas.Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.Permission.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.atlas.Permission.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.atlas.Permission.role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PERMISSION_ROLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=183,
)

_PERMISSION.fields_by_name['role'].enum_type = _PERMISSION_ROLE
_PERMISSION_ROLE.containing_type = _PERMISSION
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'eolymp.atlas.permission_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.Permission)
  })
_sym_db.RegisterMessage(Permission)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
